@@ -4,8 +4,11 @@ declare(strict_types=1);
 
 namespace Brick\VarExporter\Internal\ObjectExporter\ClosureExporter;
 
+use Override;
 use PhpParser\PrettyPrinter\Standard;
 
+use function str_repeat;
+
 /**
  * Extends the standard pretty-printer to allow for a base indent level.
  *
@@ -15,20 +18,13 @@ final class PrettyPrinter extends Standard
 {
     private int $varExporterNestingLevel = 0;
 
-    /**
-     * @param int $level
-     *
-     * @return void
-     */
-    public function setVarExporterNestingLevel(int $level) : void
+    public function setVarExporterNestingLevel(int $level): void
     {
         $this->varExporterNestingLevel = $level;
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    protected function resetState() : void
+    #[Override]
+    protected function resetState(): void
     {
         parent::resetState();
 
