@@ -6,6 +6,9 @@ namespace Brick\VarExporter\Internal\ObjectExporter;
 
 use Brick\VarExporter\Internal\ObjectExporter;
 use Override;
+use ReflectionObject;
+
+use function array_merge;
 
 /**
  * Handles instances of classes with __serialize() and __unserialize() methods.
@@ -15,14 +18,14 @@ use Override;
 final class SerializeExporter extends ObjectExporter
 {
     #[Override]
-    public function supports(\ReflectionObject $reflectionObject) : bool
+    public function supports(ReflectionObject $reflectionObject): bool
     {
         return $reflectionObject->hasMethod('__serialize')
             && $reflectionObject->hasMethod('__unserialize');
     }
 
     #[Override]
-    public function export(object $object, \ReflectionObject $reflectionObject, array $path, array $parentIds) : array
+    public function export(object $object, ReflectionObject $reflectionObject, array $path, array $parentIds): array
     {
         $lines = $this->getCreateObjectCode($reflectionObject);
 
